#!/bin/bash
# set -x 

usage() {
    echo "This command will publish feedsim data to LiveView as fast as it can accept it"
    echo ""
    echo "LiveViewLoader -t LiveViewTable -f FeedSimFile.sbfs [ -s LiveViewServer ] [ -p StreamBasePort ]"
    echo ""
    echo "Options:"
    echo "-t <LiveViewTable> - LiveView table to publish data to"
    echo "-f <FeedSimFile.sbfs> - FeedSim file that has the data to publish"
    echo "-s <LiveViewServer> - The node name of the LiveView server"
    echo "-p <StreamBasePort> - The StreamBase port of the LiveView server (NOT the LiveView port number)"
    echo "-P <LocalStreamBasePort> - The port of this Liveview loader StreamBase server (10003 by default)"
    echo "-q <RegEx> - The RegEx of the queue(s) to monitor for backup (LiveViewTable by default)"
    echo "-i <initialRate> - The initial starting publish rate."
    echo "-l <NumberOfTuples> - Send no more then NumberOfTuples, then exit."
    echo "-m <NumberOfTuples> - reduce rate when queueing is above NumberOfTuples."
    echo "-M <NumberOfTuples> - when queueing drops below NumberOfTuples, increase rate."
# Broken until 7.3.10
    echo "-T <NumberOfSeconds> - Send for no more then NumberOfSeconds, then exit."
    echo "-h - list help"
    exit -1
}

install_path=`dirname $0`

# If running in cygwin, get the correct windows path
this_platform=`uname | cut -c 1-6`
if [ "$this_platform" = "CYGWIN" ] ; then
    install_path=`cygpath -aw "$install_path"`
fi

export STREAMBASE_LIVEVIEW_TABLE=""
export STREAMBASE_LIVEVIEW_TARGET_QUEUE_REGEX=""
export STREAMBASE_LIVEVIEW_FEEDCONFIG=""

export STREAMBASE_LIVEVIEW_SERVER="localhost"

while [ "$1x" != "x" ] ; do

    if [ "$1" = "-h" ]; then
        usage
    fi
    if [ "$1" = "--help" ]; then
        usage
    fi
    if [ "$1" = "?" ]; then
        usage
    fi
    if [ "$1" = "-?" ]; then
        usage
    fi
    
    if [ "$1" = "-t" ]; then
        shift
        STREAMBASE_LIVEVIEW_TABLE=$1
        STREAMBASE_LIVEVIEW_TARGET_QUEUE_REGEX=$1.*
        shift
        continue
    fi
    
    if [ "$1" = "-f" ]; then
        shift
        STREAMBASE_LIVEVIEW_FEEDCONFIG=$1
        shift
        continue
    fi

    if [ "$1" = "-s" ]; then
        shift
        STREAMBASE_LIVEVIEW_SERVER=$1
        shift
        continue
    fi

    if [ "$1" = "-i" ]; then
        shift
        export STREAMBASE_LIVEVIEW_INITIALRATE=$1
        shift
        continue
    fi

    if [ "$1" = "-l" ]; then
        shift
        export STREAMBASE_LIVEVIEW_MAXTUPLES=$1
        shift
        continue
    fi
    
    if [ "$1" = "-m" ]; then
        shift
        export STREAMBASE_LIVEVIEW_MAX_QUEUE_SIZE=$1
        shift
        continue
    fi
    
    if [ "$1" = "-M" ]; then
        shift
        export STREAMBASE_LIVEVIEW_MIN_QUEUE_SIZE=$1
        shift
        continue
    fi

    if [ "$1" = "-T" ]; then
        shift
        export STREAMBASE_LIVEVIEW_MAXTIME=$1
        shift
        continue
    fi

    if [ "$1" = "-p" ]; then
        shift
        export STREAMBASE_PORT=$1
        shift
        continue
    fi

    if [ "$1" = "-P" ]; then
        shift
        export STREAMBASE_LOCAL_PORT=$1
        shift
        continue
    fi

    if [ "$1" = "-q" ]; then
        shift
        STREAMBASE_LIVEVIEW_TARGET_QUEUE_REGEX=$1
        shift
        continue
    fi

    echo "Unknown option"
    usage
done

if [ "$STREAMBASE_LIVEVIEW_FEEDCONFIG" = "" ]; then
    echo "You must supply a feedsim file"
    echo ""
    usage
fi

if [ "$STREAMBASE_LIVEVIEW_TABLE" = "" ]; then
    echo "You must supply a LiveView table name"
    echo ""
    usage
fi

sbd -f $install_path/sbd.sbconf $install_path/LiveViewLoader.sbapp
